from distutils.core import setup
setup(
        name ='nesterlp',
        version ='1.0',
        py_modules =['nesterlp'],
        author ='zichen',
        authon_email ='black18k@163.com',
        
        )
